@@ -1919,19 +1919,36 @@ export default function waitUntil(callback, options = {}) {
     }
 
     #[test]
-    #[should_panic(expected = "await isn't allowed in non-async function")]
     fn await_in_function_in_script() {
         let src = "function foo (p) { await p; }";
         test_parser(src, Syntax::Es(Default::default()), |p| p.parse_script());
     }
 
     #[test]
-    #[should_panic(expected = "await isn't allowed in non-async function")]
     fn await_in_function_in_program() {
         let src = "function foo (p) { await p; }";
         test_parser(src, Syntax::Es(Default::default()), |p| p.parse_program());
     }
 
+    #[test]
+    #[should_panic(expected = "await isn't allowed in non-async function")]
+    fn await_in_nested_async_function_in_module() {
+        let src = "async function foo () { function bar(x = await) {} }";
+        test_parser(src, Syntax::Es(Default::default()), |p| p.parse_module());
+    }
+
+    #[test]
+    fn await_in_nested_async_function_in_script() {
+        let src = "async function foo () { function bar(x = await) {} }";
+        test_parser(src, Syntax::Es(Default::default()), |p| p.parse_script());
+    }
+
+    #[test]
+    fn await_in_nested_async_function_in_program() {
+        let src = "async function foo () { function bar(x = await) {} }";
+        test_parser(src, Syntax::Es(Default::default()), |p| p.parse_program());
+    }
+
     #[test]
     fn top_level_await_in_block() {
         let src = "if (true) { await promise; }";
